@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.64 2006/08/07 23:53:21 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/display.c,v 1.66 2006/10/03 16:16:56 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -268,8 +268,8 @@ make_number(int *MPnumber, int base, BOOLEAN ignoreError)
     mpcmd(MPnumber, &number);
     val = fabs(number);
     if (v->error && !ignoreError) {
-        return(_("Error"));
-    }
+	  return(_("Error"));
+	}
     if ((v->dtype == ENG) ||
         (v->dtype == SCI) ||
         (v->dtype == FIX && val != 0.0 && (val > max_fix[base]))) {
@@ -399,7 +399,7 @@ MPstr_to_num(char *str, enum base_type base, int *MPval)
     int exp      = 0;
     int exp_sign = 1;
     char *lnp = get_localized_numeric_point();
-    assert(lnp && strlen(lnp) == 1);
+    assert(lnp);
 
     i = 0;
     mpcim(&i, MPval);
@@ -596,7 +596,7 @@ refresh_display()
     if (e->expression &&
 		strlen(e->expression)) {
       char *str = gc_strdup(e->expression);
-      char *ans = make_number(e->ans, v->base, FALSE);
+      char *ans = make_number(e->ans, v->base, TRUE);
       localize_number(localized, ans);
       
       str_replace(&str, "Ans", localized);
