@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.44 2006/01/09 16:30:20 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/get.c,v 1.46 2006/09/22 15:22:20 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -33,7 +33,6 @@
 #include "extern.h"
 
 static int get_bool_resource(enum res_type, int *);
-static int get_int_resource(enum res_type, int *);
 static int get_str_resource(enum res_type, char *);
 
 static void getparam(char *, char **, char *);
@@ -93,7 +92,7 @@ get_bool_resource(enum res_type rtype, int *boolval)
 
 /* Get integer resource from database. */
 
-static int
+int
 get_int_resource(enum res_type rtype, int *intval)
 {
     char *val;
@@ -384,18 +383,36 @@ read_resources()    /* Read all possible resources from the database. */
 
     if (get_str_resource(R_SYNTAX, str)) {
       for (i = 0; i < MAXSYNTAX; i++) {
-	if (EQUAL(str, Rsstr[i])) {
-	  break;
-	}
+		if (EQUAL(str, Rsstr[i])) {
+		  break;
+		}
       }
       
       if (i == MAXSYNTAX) {
-	FPRINTF(stderr, _("%s: invalid syntax mode [%s]\n"), 
-		v->progname, str);
+		FPRINTF(stderr, _("%s: invalid syntax mode [%s]\n"), 
+				v->progname, str);
       } else {
-	v->syntax = i;
+		v->syntax = i;
       }
     }
+	
+	v->bitcalculating_mode = 0; // default = off
+
+    if (get_str_resource(R_BITCALC, str)) {
+      for (i = 0; i < MAXBITCALC; i++) {
+		if (EQUAL(str, Rcstr[i])) {
+		  break;
+		}
+      }
+      
+      if (i == MAXBITCALC) {
+		FPRINTF(stderr, _("%s: invalid bitcalc choice [%s]\n"), 
+				v->progname, str);
+      } else {
+		v->bitcalculating_mode = i;
+      }
+    }
+
 
     if (get_bool_resource(R_REGS, &boolval)) {
         v->rstate = boolval;
